# Migration

This folder contains instructions (for both humans and LLMs) for how to migrate between Starsim versions. The original `v2→v3` migration instructions, which used to be this readme, is now located in `v2_v3/README.md`.